@@ -29,6 +29,7 @@ import quip.external as external
 from argparse import RawTextHelpFormatter
 from quip import __version__, yes_or_no, cprint, choose_one, color_text
 import keyring
+import platform
 
 version = __version__
 UPDATE_ACTION = ["update", "u", "up"]
@@ -263,6 +264,7 @@ class Quip:
                     sys.exit(1)
                 
                 self.update_version(self.args.version_method, self.curr_version[0])
+                self.clean_project()
             
             if self.args.forced_version is not None:
                 if len(self.curr_version) > 1:
@@ -272,7 +274,7 @@ class Quip:
                     if old_version == self.args.forced_version:
                         continue
                     self.update_version("forced", old_version, self.args.forced_version)
-                
+                    self.clean_project()
 
     def set_global_configs(self, project_name, config_path=None):
         if config_path is not None:
@@ -449,9 +451,38 @@ class Quip:
             sys.exit(1)
 
         shutil.rmtree(self.project_folder_name)
-    
-    def clean_project(self):
-        for folder in ["build", "dist", "temp", "downloads"]:
+
+    def delete_macos_hidden_files(self, dir_path):
+        logging.debug(f"Deleting MacOS Hidden Files: {dir_path}")
+        for filename in os.listdir(dir_path):
+            if filename.startswith('.') or filename.startswith('._'):
+                if filename == '.DS_Store' or filename == '.localized':
+                    os.remove(os.path.join(dir_path, filename))
+                elif filename.startswith('._'):
+                    original_filename = filename[2:]
+                    original_file_path = os.path.join(dir_path, original_filename)
+                    if os.path.exists(original_file_path):
+                        os.remove(os.path.join(dir_path, filename))
+                    else:
+                        logging.info(f"Skipping {filename} (corresponding original file not found)")
+            elif os.path.isdir(os.path.join(dir_path, filename)):
+                self.delete_macos_hidden_files(os.path.join(dir_path, filename))
+
+
+    def clean_project(self, full=True):
+        if full:
+            folders = ["build", "dist", "temp", "downloads"]
+        else:
+            folders = ["build", "dist"]
+        
+        # Clean Mac specific files
+        if platform.system() == 'Darwin':  # Check if the OS is macOS
+            self.delete_macos_hidden_files(self.join_path("."))
+        
+        if not self.args.template:
+            self.run_uip("clean")
+
+        for folder in folders:
             folder_path = self.join_path(folder)
         
             if os.path.exists(folder_path):
@@ -469,8 +500,6 @@ class Quip:
                     shutil.rmtree(folder_path)
                 except Exception as e:
                     print('Failed to delete %s. Reason: %s' % (folder_path, e))
-        if not self.args.template:
-            self.run_uip("clean")
 
     def clone_project(self, from_project_path, all_files=False, exclude_list=None):
         if not os.path.exists(from_project_path):
@@ -1186,7 +1215,7 @@ class Quip:
                         _json["variablePrefix"] = "var"    
                     else:
                         _json["variablePrefix"] = self.extension_name.replace("-", "_")
-                        if _json["variablePrefix"] > 20:
+                        if len(_json["variablePrefix"]) > 20:
                             _json["variablePrefix"] = "ext"
                 f.write(self.format_json(_json))
                 logging.debug("template.json file is updated")
